@@ -1,9 +1,9 @@
 import os
 from copy import deepcopy
 from pathlib import Path
-from typing import Sequence, Optional, List, Dict, Any
+from typing import Any, Dict, List, Optional, Sequence
 
-from git import Repo, GitCommandError
+from git import GitCommandError, Repo
 from rich.prompt import Confirm
 
 from flexlate.branch_update import (
@@ -14,52 +14,50 @@ from flexlate.cli_utils import confirm_user
 from flexlate.config_manager import ConfigManager
 from flexlate.constants import DEFAULT_MERGED_BRANCH_NAME, DEFAULT_TEMPLATE_BRANCH_NAME
 from flexlate.exc import (
-    TriedToCommitButNoChangesException,
     MergeConflictsAndAbortException,
+    TriedToCommitButNoChangesException,
+)
+from flexlate.ext_git import (
+    abort_merge,
+    assert_repo_is_in_clean_state,
+    branch_exists,
+    checkout_template_branch,
+    fast_forward_branch_without_checkout,
+    get_branch_sha,
+    get_merge_conflict_diffs,
+    merge_branch_into_current,
+    repo_has_merge_conflicts,
+    reset_branch_to_commit_without_checkout,
+    restore_initial_commit_files,
+    stage_and_commit_all,
+    temp_repo_that_pushes_to_branch,
+    update_local_branches_from_remote_without_checkout,
 )
 from flexlate.finder.multi import MultiFinder
 from flexlate.logger import log
 from flexlate.path_ops import (
-    make_all_dirs,
     location_relative_to_new_parent,
     make_absolute_path_from_possibly_relative_to_another_path,
+    make_all_dirs,
 )
 from flexlate.render.multi import MultiRenderer
 from flexlate.render.renderable import Renderable
 from flexlate.styles import (
-    print_styled,
     ACTION_REQUIRED_STYLE,
-    styled,
-    QUESTION_STYLE,
     ALERT_STYLE,
     INFO_STYLE,
+    QUESTION_STYLE,
     SUCCESS_STYLE,
+    print_styled,
+    styled,
 )
 from flexlate.template.base import Template
-from flexlate.ext_git import (
-    stage_and_commit_all,
-    merge_branch_into_current,
-    checkout_template_branch,
-    repo_has_merge_conflicts,
-    assert_repo_is_in_clean_state,
-    temp_repo_that_pushes_to_branch,
-    fast_forward_branch_without_checkout,
-    abort_merge,
-    reset_branch_to_commit_without_checkout,
-    get_branch_sha,
-    restore_initial_commit_files,
-    get_merge_conflict_diffs,
-    update_local_branches_from_remote_without_checkout,
-)
 from flexlate.template_data import TemplateData, merge_data
 from flexlate.transactions.transaction import (
     FlexlateTransaction,
     create_transaction_commit_message,
 )
-from flexlate.update.template import (
-    TemplateUpdate,
-    updates_with_updated_data,
-)
+from flexlate.update.template import TemplateUpdate, updates_with_updated_data
 
 
 class Updater:
@@ -177,19 +175,21 @@ class Updater:
             new_temp_updates = _move_update_config_locations_to_new_parent(
                 new_updates, project_root, temp_project_root
             )
+
+            # For applied templates with local add mode, with corresponding template sources that
+            # have a render_relative_root_in_output, may need to move the config
+            rendered_temp_updates = config_manager.move_local_applied_templates_if_necessary_produce_new_updates(
+                new_temp_updates,
+                project_root=temp_project_root,
+                orig_project_root=project_root,
+                renderer=renderer,
+            )
+
             # On second update, use template source path. This means that it will set the template
             # paths back to how they were originally (relative if needed), so that there will not be
             # unexpected changes from relative to absolute paths in the user configs
             config_manager.update_templates(
-                new_temp_updates, project_root=temp_project_root
-            )
-
-            # For applied templates with local add mode, with corresponding template sources that
-            # have a render_relative_root_in_output, may need to move the config
-            config_manager.move_local_applied_templates_if_necessary(
-                project_root=temp_project_root,
-                orig_project_root=project_root,
-                renderer=renderer,
+                rendered_temp_updates, project_root=temp_project_root
             )
 
             # Add back initial commit files if they have not been rendered from a template
@@ -212,18 +212,30 @@ class Updater:
             log.debug("Leaving temp directory")
 
         log.debug(f"Updating merged branch {merged_branch_name}")
-        # Now prepare the merged (output) branch, by merging the current
-        # branch into it and then the template branch into it.
-        # Update with changes from the main repo
-        log.debug(
-            f"Fast forwarding {merged_branch_name} based on {current_branch.name}"
-        )
-        fast_forward_branch_without_checkout(
-            repo, merged_branch_name, current_branch.name
-        )
+        # Now prepare the merged (output) branch
+        if not branch_exists(repo, merged_branch_name) and branch_exists(
+            repo, base_merged_branch_name
+        ):
+            # If output feature branch doesn't exist but output main branch does,
+            # start it from the main output branch
+            log.debug(
+                f"Fast forwarding {merged_branch_name} based on {base_merged_branch_name}"
+            )
+            fast_forward_branch_without_checkout(
+                repo, merged_branch_name, base_merged_branch_name
+            )
+
+        # Now get the output branch updated by merging the current branch into it
+        log.debug(f"Merging {current_branch.name} into {merged_branch_name}")
+        # If the feature output branch exists, check it out
+        # If the feature output branch doesn't exist:
+        #  If the main output branch exists, start it from the main output branch
+        #  If the main output branch doesn't exist, start it from the current branch
+        checkout_template_branch(repo, merged_branch_name, base_merged_branch_name)
+        merge_branch_into_current(repo, current_branch.name)
+
         # Update with template changes
         log.debug(f"Merging {template_branch_name} into {merged_branch_name}")
-        checkout_template_branch(repo, merged_branch_name, base_merged_branch_name)
         merge_branch_into_current(repo, template_branch_name)
 
         if repo_has_merge_conflicts(repo):
