@@ -1,6 +1,6 @@
 from flexlate.render.renderable import Renderable
 from flexlate.template.copier import CopierTemplate
-from tests.config import GENERATED_FILES_DIR
+from tests import config
 from tests.fixtures.template import *
 
 
@@ -8,14 +8,16 @@ from tests.fixtures.template import *
 def cookiecutter_one_renderable(
     cookiecutter_one_template: CookiecutterTemplate,
 ) -> Renderable:
-    return Renderable(template=cookiecutter_one_template, out_root=GENERATED_FILES_DIR)
+    return Renderable(
+        template=cookiecutter_one_template, out_root=config.GENERATED_FILES_DIR
+    )
 
 
 @pytest.fixture
 def copier_one_renderable(
     copier_one_template: CopierTemplate,
 ) -> Renderable:
-    return Renderable(template=copier_one_template, out_root=GENERATED_FILES_DIR)
+    return Renderable(template=copier_one_template, out_root=config.GENERATED_FILES_DIR)
 
 
 @pytest.fixture
@@ -23,7 +25,7 @@ def copier_output_subdir_renderable(
     copier_output_subdir_template: CopierTemplate,
 ) -> Renderable:
     return Renderable(
-        template=copier_output_subdir_template, out_root=GENERATED_FILES_DIR
+        template=copier_output_subdir_template, out_root=config.GENERATED_FILES_DIR
     )
 
 
@@ -31,7 +33,9 @@ def copier_output_subdir_renderable(
 def cookiecutter_two_renderable(
     cookiecutter_two_template: CookiecutterTemplate,
 ) -> Renderable:
-    return Renderable(template=cookiecutter_two_template, out_root=GENERATED_FILES_DIR)
+    return Renderable(
+        template=cookiecutter_two_template, out_root=config.GENERATED_FILES_DIR
+    )
 
 
 @pytest.fixture
