@@ -5,22 +5,23 @@ from flexlate import branch_update
 from flexlate.add_mode import AddMode
 from flexlate.config import FlexlateConfig
 from flexlate.exc import (
-    CannotRemoveTemplateSourceException,
     CannotRemoveAppliedTemplateException,
+    CannotRemoveTemplateSourceException,
 )
 from flexlate.ext_git import repo_has_merge_conflicts
 from flexlate.remover import Remover
 from flexlate.transactions.transaction import FlexlateTransaction
+from tests import config as test_config
 from tests.config import (
     COOKIECUTTER_ONE_NAME,
-    COOKIECUTTER_TWO_NAME,
     COOKIECUTTER_REMOTE_NAME,
+    COOKIECUTTER_TWO_NAME,
 )
 from tests.fixtures.templated_repo import *
 from tests.fixtures.transaction import (
-    remove_source_transaction,
-    remove_output_transaction,
     add_source_transaction,
+    remove_output_transaction,
+    remove_source_transaction,
 )
 from tests.gitutils import accept_theirs_in_merge_conflict
 
@@ -31,8 +32,8 @@ def test_remove_template_source(
 ):
     repo = repo_with_cookiecutter_one_template_source
     remover = Remover()
-    config_path = GENERATED_REPO_DIR / "flexlate.json"
-    with change_directory_to(GENERATED_REPO_DIR):
+    config_path = test_config.GENERATED_REPO_DIR / "flexlate.json"
+    with change_directory_to(test_config.GENERATED_REPO_DIR):
         assert config_path.exists()
         remover.remove_template_source(
             repo, COOKIECUTTER_ONE_NAME, remove_source_transaction
@@ -49,8 +50,8 @@ def test_remove_template_source_when_multiple_exist(
     repo = repo_with_cookiecutter_one_template_source
     remover = Remover()
     adder = Adder()
-    config_path = GENERATED_REPO_DIR / "flexlate.json"
-    with change_directory_to(GENERATED_REPO_DIR):
+    config_path = test_config.GENERATED_REPO_DIR / "flexlate.json"
+    with change_directory_to(test_config.GENERATED_REPO_DIR):
         adder.add_template_source(
             repo, cookiecutter_two_template, add_source_transaction
         )
@@ -74,8 +75,8 @@ def test_remove_template_source_when_outputs_from_another_source_exist(
     repo = repo_with_cookiecutter_one_template_source_and_output
     remover = Remover()
     adder = Adder()
-    config_path = GENERATED_REPO_DIR / "flexlate.json"
-    with change_directory_to(GENERATED_REPO_DIR):
+    config_path = test_config.GENERATED_REPO_DIR / "flexlate.json"
+    with change_directory_to(test_config.GENERATED_REPO_DIR):
         adder.add_template_source(
             repo, cookiecutter_two_template, add_source_transaction
         )
@@ -91,7 +92,7 @@ def test_remove_template_source_when_outputs_from_another_source_exist(
     assert template_source.name == COOKIECUTTER_ONE_NAME
 
     # Check no side effects
-    unrelated_config_path = GENERATED_REPO_DIR / "b" / "flexlate.json"
+    unrelated_config_path = test_config.GENERATED_REPO_DIR / "b" / "flexlate.json"
     config = FlexlateConfig.load(unrelated_config_path)
     assert len(config.template_sources) == 0
     assert len(config.applied_templates) == 1
@@ -109,7 +110,7 @@ def test_remove_non_existing_template_source(
 ):
     repo = repo_with_placeholder_committed
     remover = Remover()
-    with change_directory_to(GENERATED_REPO_DIR):
+    with change_directory_to(test_config.GENERATED_REPO_DIR):
         with pytest.raises(CannotRemoveTemplateSourceException) as exc_info:
             remover.remove_template_source(
                 repo, COOKIECUTTER_ONE_NAME, remove_source_transaction
@@ -123,7 +124,7 @@ def test_remove_template_source_when_output_exists(
 ):
     repo = repo_with_cookiecutter_one_template_source_and_output
     remover = Remover()
-    with change_directory_to(GENERATED_REPO_DIR):
+    with change_directory_to(test_config.GENERATED_REPO_DIR):
         with pytest.raises(CannotRemoveTemplateSourceException) as exc_info:
             remover.remove_template_source(
                 repo, COOKIECUTTER_ONE_NAME, remove_source_transaction
@@ -137,7 +138,7 @@ def test_remove_template_source_with_merge_conflict_resolution(
 ):
     repo = repo_with_cookiecutter_remote_version_one_template_source_that_will_have_merge_conflict_on_flexlate_operation
     remover = Remover()
-    config_path = GENERATED_REPO_DIR / "flexlate.json"
+    config_path = test_config.GENERATED_REPO_DIR / "flexlate.json"
 
     def _resolve_conflicts_then_type_yes(prompt: str) -> bool:
         assert repo_has_merge_conflicts(repo)
@@ -145,7 +146,7 @@ def test_remove_template_source_with_merge_conflict_resolution(
         stage_and_commit_all(repo, "Manually resolve conflicts")
         return True
 
-    with change_directory_to(GENERATED_REPO_DIR):
+    with change_directory_to(test_config.GENERATED_REPO_DIR):
         assert config_path.exists()
         with patch.object(
             branch_update, "confirm_user", _resolve_conflicts_then_type_yes
@@ -162,9 +163,9 @@ def test_remove_applied_template(
 ):
     repo = repo_with_template_branch_from_cookiecutter_one
     remover = Remover()
-    config_path = GENERATED_REPO_DIR / "flexlate.json"
-    output_path = GENERATED_REPO_DIR / "b" / "text.txt"
-    with change_directory_to(GENERATED_REPO_DIR):
+    config_path = test_config.GENERATED_REPO_DIR / "flexlate.json"
+    output_path = test_config.GENERATED_REPO_DIR / "b" / "text.txt"
+    with change_directory_to(test_config.GENERATED_REPO_DIR):
         assert output_path.read_text() == "b"
         remover.remove_applied_template_and_output(
             repo, COOKIECUTTER_ONE_NAME, remove_output_transaction
@@ -182,7 +183,7 @@ def test_remove_applied_template_that_does_not_exist(
 ):
     repo = repo_with_cookiecutter_one_template_source
     remover = Remover()
-    with change_directory_to(GENERATED_REPO_DIR):
+    with change_directory_to(test_config.GENERATED_REPO_DIR):
         with pytest.raises(CannotRemoveAppliedTemplateException) as exc_info:
             remover.remove_applied_template_and_output(
                 repo, COOKIECUTTER_ONE_NAME, remove_output_transaction
@@ -199,7 +200,7 @@ def test_remove_applied_template_when_multiple_exist(
     repo = repo_with_cookiecutter_one_template_source_and_output
     remover = Remover()
     adder = Adder()
-    subdir = GENERATED_REPO_DIR / "subdir"
+    subdir = test_config.GENERATED_REPO_DIR / "subdir"
     subdir.mkdir()
     config_path = subdir / "b" / "flexlate.json"
     output_path = subdir / "b" / "text.txt"
@@ -218,7 +219,7 @@ def test_remove_applied_template_when_multiple_exist(
     assert not config_path.exists()
 
     # Ensure no side effects
-    unrelated_config_path = GENERATED_REPO_DIR / "b" / "flexlate.json"
+    unrelated_config_path = test_config.GENERATED_REPO_DIR / "b" / "flexlate.json"
     config = FlexlateConfig.load(unrelated_config_path)
     assert len(config.template_sources) == 0
     assert len(config.applied_templates) == 1
@@ -236,8 +237,8 @@ def test_remove_applied_template_with_merge_conflict_resolution(
 ):
     repo = repo_with_cookiecutter_remote_version_one_template_source_and_output_that_will_have_merge_conflict_on_flexlate_operation
     remover = Remover()
-    config_path = GENERATED_REPO_DIR / "flexlate.json"
-    output_path = GENERATED_REPO_DIR / "abc" / "abc.txt"
+    config_path = test_config.GENERATED_REPO_DIR / "flexlate.json"
+    output_path = test_config.GENERATED_REPO_DIR / "abc" / "abc.txt"
 
     def _resolve_conflicts_then_type_yes(prompt: str) -> bool:
         assert repo_has_merge_conflicts(repo)
@@ -245,7 +246,7 @@ def test_remove_applied_template_with_merge_conflict_resolution(
         stage_and_commit_all(repo, "Manually resolve conflicts")
         return True
 
-    with change_directory_to(GENERATED_REPO_DIR):
+    with change_directory_to(test_config.GENERATED_REPO_DIR):
         assert output_path.read_text() == "some new header\nvalue"
         with patch.object(
             branch_update, "confirm_user", _resolve_conflicts_then_type_yes
